/*@
theory uses Base {
  int: TYPE = Base.int;
  intArray: TYPE = Base.IntArray;
  nullArray: intArray = Base.nullIntArray;
  notFound: PREDICATE(intArray, int, int) =
    PRED(a: intArray, n: int, x: int): 
      FORALL(i: INT): 0 <= i AND i < n => a.value[i] /= x;
  isSorted: PREDICATE(intArray, int) =
    PRED(a: intArray, n: int): 
      FORALL(i: INT): 1 <= i AND i < n => a.value[i-1] <= a.value[i];
  sortedLemma: FORMULA
    FORALL(a: intArray, n: NAT): 
      n <= Base.MAX_INT AND isSorted(a, n) =>
      (FORALL(i, j: int): 0 <= i AND i <= j AND j < n =>
        a.value[i] <= a.value[j]);
}
@*/
class Arrays
{
  public static int search(int[] a, int x) /*@
    requires (VAR a).null = FALSE;
    ensures 
      LET result = VALUE@NEXT, n = (VAR a).length IN
      IF result = -1 THEN
        notFound(VAR a, n, VAR x)
      ELSE
         0 <= result AND result < n AND
         notFound(VAR a, result, VAR x) AND
         (VAR a).value[result] = VAR x
      ENDIF;
  @*/
  {
    int n = a.length;
    for (int i=0; i< n; i++) /*@
      invariant (VAR a).null = FALSE AND VAR n = (VAR a).length
            AND 0 <= VAR i AND VAR i <= VAR n
            AND notFound(VAR a, VAR i, VAR x)
            AND (RETURNS@NEXT =>
                   VAR i < VAR n AND
                   (VAR a).value[VAR i] = VAR x AND
                   VALUE@NEXT = VAR i);
      decreases VAR n - VAR i;  
    @*/
    {
      if (a[i] == x) return i;
    }
    return -1;
  }
  
  public static boolean isSorted(int[] a) /*@
    requires (VAR a).null = FALSE;
    ensures (VALUE@NEXT=TRUE) <=> isSorted(VAR a, (VAR a).length);
  @*/
  {
    int n = a.length;
    for (int i=1; i<n; i++)
    /*@
      invariant (VAR a).null = FALSE AND VAR n = (VAR a).length
        AND 1 <= VAR i AND (VAR n >= 1 => VAR i <= VAR n)
        AND (EXECUTES@NEXT => isSorted(VAR a, VAR i))
        AND (RETURNS@NEXT => 
               VALUE@NEXT = FALSE AND
               VAR i < VAR n AND
               (VAR a).value[VAR i-1] > (VAR a).value[VAR i]);
      decreases VAR n - VAR i + 1;
    @*/
    {
      if (a[i-1] > a[i]) return false;
    }
    return true;
  }
  
  public static int binarySearch(int[] a, int x) /*@
    requires 
      (VAR a).null = FALSE AND 2*((VAR a).length+1) < Base.MAX_INT AND
      isSorted(VAR a, (VAR a).length);
    ensures 
      LET result = VALUE@NEXT, n = (VAR a).length IN
      IF result = -1 THEN
        notFound(VAR a, n, VAR x)
      ELSE
         0 <= result AND result < n AND
         (VAR a).value[result] = VAR x
      ENDIF;
  @*/
  {
    int left = 0;
    int right = a.length-1;
    while (left <= right) /*@
      invariant 
        LET n = (VAR a).length, result = VALUE@NEXT IN
        (VAR a).null = FALSE AND 2*(n+1) < Base.MAX_INT AND 
        isSorted(VAR a, n) AND
        0 <= VAR left AND VAR left <= n AND
        -1 <= VAR right AND VAR right < n AND
        VAR left <= VAR right+1 AND
        (FORALL(i: INT): 0 <= i AND i < VAR left => 
          (VAR a).value[i] /= VAR x) AND
        (FORALL(i: INT): VAR right+1 <= i AND i < n => 
          (VAR a).value[i] /= VAR x) AND
        (RETURNS@NEXT =>
           0 <= result AND result < n AND 
           (VAR a).value[result] = VAR x);
      decreases VAR right - VAR left + 1;
    @*/
    {
      int mid = (left+right)/2;
      if (a[mid] == x) return mid;
      if (a[mid] < x)
        left = mid+1;
      else
        right = mid-1;
    }
    return -1;
  }
}




















