// -------------------------------------------------------------
// A demonstration of MiniJava and its specification language
// -------------------------------------------------------------
/*@ 
theory uses Math {
  // CVC4 segfaults with this
  // the mathematical factorial function
  // factorial: NAT -> NAT = Math.factorial;

  // CVC4 does not know anything at all about non-linear arithmetic
  C: AXIOM FORALL(n1,n2:NAT): n1*n2=n2*n1;
}
@*/
public class Factorial
{
  // ------------------------------------------------------------
  // a program function that computes the factorial of n
  // ------------------------------------------------------------
  public static int fac(int n) /*@
    // if n is negative, the factorial is not defined
    requires VAR n >= 0 AND Math.factorial(VAR n) <= Base.MAX_INT;
    ensures VALUE@NEXT = Math.factorial(VAR n);
  @*/
  {
    int i=1;
    int p=1;
    while (i <= n) /*@
      invariant VAR n >= 0 AND Math.factorial(VAR n) <= Base.MAX_INT
            AND 1 <= VAR i AND VAR i <= VAR n+1 
            AND VAR p = Math.factorial(VAR i -1);
      decreases VAR n - VAR i + 1;
    @*/
    {
      p = p*i;
      i = i+1;
    }
    return p;
  }
  
  // ------------------------------------------------------------
  // a recursive implementation of the factorial function
  // ------------------------------------------------------------
  public static int fac0(int n) /*@
    // if n is negative, the factorial is not defined
    requires VAR n >= 0 AND Math.factorial(VAR n) <= Base.MAX_INT;
    ensures VALUE@NEXT = Math.factorial(VAR n);
    decreases VAR n;
  @*/
  {
    if (n <= 0) return 1;
    int n0 = fac0(n-1);
    return n*n0;
  }
  
  // ------------------------------------------------------------
  // a mutually recursive implementation of the factorial function
  // ------------------------------------------------------------
  public static int fac1(int n) /*@
    requires VAR n >= 0 AND Math.factorial(VAR n) <= Base.MAX_INT;
    ensures VALUE@NEXT = Math.factorial(VAR n);
    decreases VAR n;
  @*/
  {
    if (n <= 0) return 1;
    int n0 = fac2(n-1);
    return n*n0;
  }
  public static int fac2(int n) /*@
    requires VAR n >= 0 AND Math.factorial(VAR n) <= Base.MAX_INT;
    ensures VALUE@NEXT = Math.factorial(VAR n);
    decreases VAR n;
  @*/
  {
    if (n <= 0) return 1;
    int n0 = fac1(n-1);
    return n*n0;
  }
}







































































