// ----------------------------------------------------------------------------
// TextOutputStream.java
// Mapping of an OutputStream object to a Text widget.
// $Id: TextOutputStream.java,v 1.2 2011/04/11 16:35:27 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.SWT;

import java.io.*;
import org.eclipse.swt.widgets.*;

/**
 * 
 * Mapping of an OutputStream object to a Text widget.
 *
 */
public final class TextOutputStream extends OutputStream
{
  // the widget
  private Text output;
  
  /****************************************************************************
   * Create an output stream from a Text widget.
   * @param output the widget that displays the output written to the stream.
   **************************************************************************/
  public TextOutputStream(Text output)
  {
    this.output = output;
  }
  
  /****************************************************************************
   * Write a section of an byte array to the output stream.
   * @param b the byte array.
   * @param offset the array index where the section starts.
   * @param length the length of the section.
   ***************************************************************************/
  public void write(byte[] b, int offset, int length)
  {
    final String text = new String(b, offset, length);
    if (output.isDisposed()) return;
    output.getDisplay().syncExec(new Runnable() {
      public void run() {
        if (output.isDisposed()) return;
        output.append(text);
        output.redraw();
      }
    });
  }

  /****************************************************************************
   * Write a byte array to the output stream.
   * @param b the byte array written
   ***************************************************************************/
  public void write(byte[] b)
  {
    write(b, 0, b.length);
  }

  /****************************************************************************
   * Write a byte to the output stream.
   * @param b the byte written
   ***************************************************************************/
  public void write(int b)
  {
    byte[] a = new byte[1];
    a[0] = (byte)b;
    write(a);
  }
}
