// ----------------------------------------------------------------------------
// MethodSymbol.java
// A symbol denoting a method.
// $Id: MethodSymbol.java,v 1.8 2010/12/20 18:58:06 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Semantics;

import fmrisc.ProgramExplorer.Syntax.*;
import fmrisc.ProgramExplorer.Syntax.Program.Parameter;
import fmrisc.ProgramExplorer.Syntax.Program.TypeExpression;
import fmrisc.ProgramExplorer.Syntax.Program.VoidType;
import fmrisc.ProgramExplorer.Syntax.Logic.*;
import fmrisc.ProgramExplorer.InOut.*;

/**
 * 
 * A symbol denoting a method.
 *
 */
public abstract class MethodSymbol extends ParamSymbol implements GlobalSymbol
{  
  private final TypeExpression rtype; // the method's return type
  private final Type ltype;           // the logic return type
  
  /***************************************************************************
   * Construct method symbol from declaration.
   * @param csymbol the symbol of the class holding the declaration.
   * @param name the name of the symbol.
   * @param params the parameters
   * @param atypes the argument types of its arguments.
   * @param rtype the return type.
   * @param error the stream for printing errors.
   **************************************************************************/
  protected MethodSymbol(ClassSymbol csymbol, 
    Identifier name, Parameter[] params, TypeExpression[] atypes, 
    TypeExpression rtype, ErrorStream error)
  {
    super(csymbol, name, params, atypes, error);
    this.rtype = rtype;
    if (rtype instanceof VoidType)
    {
      this.ltype = null;
    }
    else
    {
      TypeTranslator translator = csymbol.getPackage().getTypeTranslator();
      this.ltype = translator.logicType(rtype);
    }
  }
  
  /****************************************************************************
   * Get return type of the method.
   * @return the return type.
   ***************************************************************************/
  public TypeExpression getReturnType()
  {
    return rtype;
  }
  
  /****************************************************************************
   * Get logic return type of the method.
   * @return the logic return type (null for void).
   ***************************************************************************/
  public Type getLogicReturnType()
  {
    return ltype;
  }
}