// ----------------------------------------------------------------------------
// PreStateCloner.java
// Clone a formula transforming all state references to the pre-state.
// $Id: PreStateCloner.java,v 1.6 2011/09/30 15:47:29 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Semantics;

import fmrisc.ProgramExplorer.Syntax.*;
import fmrisc.ProgramExplorer.Syntax.Logic.*;

/**
 * 
 * Clone a formula transforming all state references to the pre-state.
 *
 */
public final class PreStateCloner extends ASTCloner
{
  /****************************************************************************
   * Create a clone (deep copy) of a tree denoting a logic entity replacing
   * all post-state references by prestate references.
   * @param tree the tree to be cloned 
   * @return the clone of the tree 
   ***************************************************************************/
  public static AST clone(AST tree)
  {
    PreStateCloner cloner = new PreStateCloner();
    return cloner.clone0(tree);
  }
  
  public void visit(PostVariable tree) 
  { 
    result = PreVariable.construct((Name)clone(tree.getName()));
    Type type = tree.getType();
    if (type != null) ((Term)result).setType(type);
  }
  
  public void visit(NewState tree) 
  { 
    result = OldState.construct();
    Type type = tree.getType();
    if (type != null) ((Term)result).setType(type);
  }
}
