// ----------------------------------------------------------------------------
// ReferencedExcs.java
// Compute the exception types referenced by an expression.
// $Id: ReferencedExcs.java,v 1.8 2011/09/30 15:47:30 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for ClassSymbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Semantics;

import fmrisc.ProgramExplorer.*;
import fmrisc.ProgramExplorer.Syntax.*;
import fmrisc.ProgramExplorer.Syntax.Logic.*;

import java.util.*;

/**
 * 
 * Compute the exception types referenced by an expression.
 *
 */
public final class ReferencedExcs extends ASTVisitorBase
{
  /***************************************************************************
   * Compute referenced exceptions.
   * @param tree the expression.
   * @return a collection of the symbols of the exceptions referenced by tree. 
   **************************************************************************/
  public static Collection<ClassSymbol> compute(AST tree)
  {
    ReferencedExcs ref = new ReferencedExcs();
    ref.add(tree);
    return ref.getResult();
  }
  
  /***************************************************************************
   * Add references from the denoted tree.
   * @param tree the tree.
   **************************************************************************/
  public void add(AST tree)
  {
    tree.accept(this);
  }
  
  /***************************************************************************
   * Get the result of the computation.
   * @return the result.
   **************************************************************************/
  public Collection<ClassSymbol> getResult()
  {
    return symbols;
  }
  
  // the collection of symbols computed up to now
  private Collection<ClassSymbol> symbols = new SetClass<ClassSymbol>();
  
  /****************************************************************************
   * Process formula.
   * @param formula the formula to be processed.
   ***************************************************************************/
  public void visit(StateThrowsException formula) 
  { 
    ClassSymbol symbol = (ClassSymbol)formula.getException().getSymbol();
    if (symbol == null) 
      Main.internalError("exception without symbol");
    symbols.add(symbol);
  }
}


