// ----------------------------------------------------------------------------
// AtomicType.java
// An atomic type.
// $Id: AtomicType.java,v 1.8 2017/07/04 08:04:38 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the types of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * 
 * An atomic type.
 *
 */
public class AtomicType extends TypeBase
{
  private final String name;
  
  /****************************************************************************
   * Construct atomic type.
   * @param name the type name.
   * @return the type.
   ***************************************************************************/
  public static AtomicType construct(String name)
  {
    return new AtomicType(name);
  }
  
  /****************************************************************************
   * Construct atomic type.
   * @param name the type name.
   ***************************************************************************/
  protected AtomicType(String name)
  {
    this.name = name;
  }
  
  /****************************************************************************
   * Get type name.
   * @return the type name.
   ***************************************************************************/
  public String getName()
  {
    return name;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}
