// ----------------------------------------------------------------------------
// ExpressionBase.java
// Base class of any kind of logical expression.
// $Id: ExpressionBase.java,v 1.8 2011/09/30 15:47:33 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.*;
import fmrisc.ProgramExplorer.InOut.*;

/**
 * 
 * Base class of any kind of logical expression.
 *
 */
public abstract class ExpressionBase extends ASTLogicBase implements Expression
{
  private SourcePosition position = null;
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    super.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Set the position of this node in the source code.
   * @param position the source code position.
   **************************************************************************/
  public void setPosition(SourcePosition position)
  {
    this.position = position;
  }
  
  /***************************************************************************
   * Get the position of this node in the source code (may be null).
   * @return the source code position.
   **************************************************************************/
  public SourcePosition getPosition()
  {
    return position;
  }
  
  /***************************************************************************
   * Get precedence value of the expression operator 
   * (higher precedence value means higher binding power)
   **************************************************************************/
  public int getPrecedence()
  {
    // default is highest precedence
    return 9999;
  }
  
  /***************************************************************************
   * True if "(e1 op e2) op e3" can be printed as "e1 op e2 op e3"
   * @return true if above printing is possible.
   **************************************************************************/
  public boolean isLeftAssociative()
  {
    // most binary operators bind this way
    return true;
  }
  
  /***************************************************************************
   * True if "e1 op (e2 op e3)" can be printed as "e1 op e2 op e3"
   * @return true if above printing is possible.
   **************************************************************************/
  public boolean isRightAssociative()
  {
    // most binary operators do not bind this way
    return false;
  }
}
