// ----------------------------------------------------------------------------
// LetTerm.java
// A term with local value definitions.
// $Id: LetTerm.java,v 1.6 2011/09/30 15:47:32 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.ASTVisitor;

/**
 * 
 * A term with local value definitions.
 *
 */
public final class LetTerm extends LetExpression implements Term
{
  private Type type = null; // the type annotation
  
  /****************************************************************************
   * Set type annotation of term.
   * @param type the type annotation.
   ***************************************************************************/
  public void setType(Type type)
  {
    this.type = type;
  }
  
  /****************************************************************************
   * Set type annotation of term.
   * @return the type annotation.
   ***************************************************************************/
  public Type getType()
  {
    return type;
  }
  
  /***************************************************************************
   * Construct term with local value definitions.
   * @param d the definitions.
   * @param b the body of the term.
   * @return the term
   **************************************************************************/
  public static LetTerm construct(ValueDefinition[] d, Term b)
  {
    return new LetTerm(d, b);
  }
  
  /***************************************************************************
   * Construct term with local value definitions.
   * @param d the definitions.
   * @param b the body of the term.
   **************************************************************************/
  private LetTerm(ValueDefinition[] d, Term b)
  {
    super(d, b);
  }
  
  /***************************************************************************
   * Get definitions.
   * @return the definitions.
   **************************************************************************/
  public ValueDefinition[] getDefinitions()
  {
    return (ValueDefinition[])definitions;
  }
  
  /***************************************************************************
   * Get body.
   * @return the body.
   **************************************************************************/
  public Term getBody()
  {
    return (Term)body;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}
