// ----------------------------------------------------------------------------
// NegationTerm.java
// An arithmetic negation term.
// $Id: NegationTerm.java,v 1.6 2017/07/04 08:04:38 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.ASTVisitorOld;
import fmrisc.ProgramExplorer.Syntax.ASTVisitor;

/**
 * 
 * An arithmetic negation term.
 *
 */
public final class NegationTerm extends UnaryTerm
{
  public final static int precedence  = 50; // see SpecLang.g
  public final static String operator = "-";
  
  /****************************************************************************
   * Construct an arithmetic negation Term.
   * @param base the base Term.
   * @return the term.
   ***************************************************************************/
  public static NegationTerm construct(Term base)
  {
    return new NegationTerm(base);
  }
  
  /****************************************************************************
   * Construct an arithmetic negation Term.
   * @param base the base Term.
   ***************************************************************************/
  private NegationTerm(Term base)
  {
    super(base);
  }
  
  /***************************************************************************
   * Get precedence value of the Term operator 
   * (higher precedence value means higher binding power)
   **************************************************************************/
  public int getPrecedence()
  {
    return precedence;
  }
  
  /***************************************************************************
   * Get textual representation of operator.
   **************************************************************************/
  public String getOperator()
  {
    return operator;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}
