// ----------------------------------------------------------------------------
// PostfixApplication.java
// A postfix application of a predicate.
// $Id: PostfixFormula.java,v 1.5 2011/09/30 15:47:33 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * 
 * A postfix application of a predicate.
 *
 */
public abstract class PostfixFormula extends PostfixApplication implements Formula
{ 
  public final static int precedence = 70; // see SpecLang.g
  
  /***************************************************************************
   * Construct postfix application of a predicate.
   * @param arg the argument to which the predicate is applied.
   * @param pred the predicate that is applied.
   **************************************************************************/
  protected PostfixFormula(Term arg, Identifier pred)
  {
    super(arg, pred);
  }
  
  /***************************************************************************
   * Get the argument.
   * @return the argument.
   **************************************************************************/
  public Term getArgument()
  {
    return (Term)arg;
  }
  
  /***************************************************************************
   * Get precedence value of the formula operator 
   * (higher precedence value means higher binding power)
   **************************************************************************/
  public int getPrecedence()
  {
    return precedence;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}
