// ----------------------------------------------------------------------------
// StateThrowsException.java
// The statement that a state throws a particular exception.
// $Id: StateThrowsException.java,v 1.6 2011/09/30 15:47:33 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * 
 * The statement that a state throws a particular exception.
 *
 */
public final class StateThrowsException extends PostfixFormula
{
  private final Name exception;
  
  /****************************************************************************
   * Construct the statement that a state throws a particular exception
   * @param arg the argument denoting the state.
   * @param exception the name of the exception.
   * @return the statement.
   ***************************************************************************/
  public static StateThrowsException construct(Term arg, Name exception)
  {
    return new StateThrowsException(arg, exception);
  }
  
  /****************************************************************************
   * Construct the statement that a state throws a particular exception
   * @param arg the argument denoting the state.
   * @param exception the name of the exception.
   ***************************************************************************/
  private StateThrowsException(Term arg, Name exception)
  {
    super(arg, Identifier.construct("THROWS"));
    this.exception = exception;
  }
  
  /****************************************************************************
   * Get the name of the exception.
   * @return the exception name.
   ***************************************************************************/
  public Name getException()
  {
    return exception;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
    exception.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    exception.accept(visitor);
  }
}