// ----------------------------------------------------------------------------
// StringType.java
// The type of character strings.
// $Id: StringType.java,v 1.5 2017/07/04 08:04:38 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the types of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.ASTVisitor;

/**
 * 
 * The type of character strings.
 *
 */
public final class StringType extends AtomicType
{ 
  // name of type
  public static final String stringKeyword = "STRING";
  
  // same instance is returned
  private static final StringType type = new StringType();
  
  /****************************************************************************
   * Construct the type.
   * @return the type.
   ***************************************************************************/
  public static StringType construct()
  {
    return type;
  }
  
  /****************************************************************************
   * Construct the type.
   ***************************************************************************/
  private StringType()
  {
    super(stringKeyword);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}


