// ----------------------------------------------------------------------------
// SubType.java
// A subtype.
// $Id: SubType.java,v 1.8 2017/07/04 08:04:38 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the types of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * 
 * An subtype.
 *
 */
public final class SubType extends TypeBase
{
  public final static String keyword = "SUBTYPE";
  
  private final Term predicate;
  private Type base;             // base type, set in type checking.
  
  /****************************************************************************
   * Construct subtype.
   * @param predicate the predicate term.
   * @return the type.
   ***************************************************************************/
  public static SubType construct(Term predicate)
  {
    return new SubType(predicate);
  }
  
  /****************************************************************************
   * Construct subtype.
   * @param predicate the predicate term.
   ***************************************************************************/
  private SubType(Term predicate)
  {
    this.predicate = predicate;
  }
  
  /****************************************************************************
   * Get predicate type.
   * @return the predicate type.
   ***************************************************************************/
  public Term getPredicate()
  {
    return predicate;
  }

  /****************************************************************************
   * Set (non-subtype) base type.
   * @param base the (non-subtype) base type.
   ***************************************************************************/
  public void setBase(Type base)
  {
    this.base = base;
  }
  
  /****************************************************************************
   * Returns (non-subtype) base type.
   * @return the (non-subtype) base type.
   ***************************************************************************/
  public Type getBase()
  {
    return base;
  }

  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
    predicate.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    predicate.accept(visitor);
  }
}

