// ----------------------------------------------------------------------------
// TypeDefinition.java
// The definition of a type.
// $Id: TypeDefinition.java,v 1.4 2011/09/30 15:47:33 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * 
 * The definition of a type.
 *
 */
public final class TypeDefinition extends TypeDeclaration implements Definition
{
  private Type type;
  
  /****************************************************************************
   * Create new declaration of a constant denoting a type.
   * @param name the name of the constant.
   * @param type the value of the constant
   * @return the definition
   ***************************************************************************/
  public static TypeDefinition construct(Identifier name, Type type)
  {
    return new TypeDefinition(name, type);
  }
    
  /****************************************************************************
   * Create new definition of a constant denoting a type.
   * @param name the name of the constant.
   * @param type the value of the constant
   * @return the definition
   ***************************************************************************/
  protected TypeDefinition(Identifier name, Type type)
  {
    super(name);
    this.type = type;
  }
  
  /***************************************************************************
   * Get the type value.
   * @return the type value.
   **************************************************************************/
  public Type getValue()
  {
    return type;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
    type.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    type.accept(visitor);
  }
}
