// ----------------------------------------------------------------------------
// UnaryExpression.java
// Base class of unary expressions.
// $Id: UnaryExpression.java,v 1.6 2011/09/30 15:47:32 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * 
 * Base class of unary expressions.
 *
 */
public abstract class UnaryExpression extends ExpressionBase
{
  protected Expression base;
  
  /****************************************************************************
   * Construct unary expression.
   * @param base the base expression
   ***************************************************************************/
  protected UnaryExpression(Expression base)
  {
    this.base = base;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    super.accept(visitor);
    base.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    base.accept(visitor);
  }
  
  /***************************************************************************
   * Get base expression.
   * @return the base expression.
   **************************************************************************/
  public Expression getBase()
  {
    return (Expression)base;
  }
  
  /***************************************************************************
   * Get string representation of (outmost) operator the expression.
   * @return string representation of the operator.
   **************************************************************************/
  public abstract String getOperator();
}
