// ----------------------------------------------------------------------------
// BlockStatement.java
// A block statement i.e. a sequence of statements with a scope
// $Id: BlockStatement.java,v 1.6 2017/07/04 08:04:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Program;

import java.util.*;
import fmrisc.ProgramExplorer.Syntax.*;

/**
 * A block statement i.e. a sequence of statements with a scope
 */
public final class BlockStatement extends StatementBase
{
  public final Statement[] stats;
  
  /***************************************************************************
   * Construct a block statement
   * @param stats the sequence of statements
   * @return the statement.
   **************************************************************************/
  public static BlockStatement construct(Vector<Statement> stats)
  {
    return construct(stats.toArray(new Statement[stats.size()]));
  } 
  
  /***************************************************************************
   * Construct a block statement
   * @param stats the sequence of statements
   * @return the statement.
   **************************************************************************/
  public static BlockStatement construct(Statement[] stats)
  {
    return new BlockStatement(stats);
  } 
  
  /***************************************************************************
   * Construct a block statement
   * @param stats the sequence of statements
   **************************************************************************/
  private BlockStatement(Statement[] stats)
  {
    this.stats = stats;
  }    
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
    accept(stats, visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    accept(stats, visitor);
  }
  
  /****************************************************************************
   * Get type of statement.
   * @return a string identifying the type of statement.
   ***************************************************************************/
  public String getKind()
  {
    return "block";
  }
}
