// ----------------------------------------------------------------------------
// DividesExpression.java
// A quotient expression
// $Id: DividesExpression.java,v 1.4 2017/07/04 08:04:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Program;

import fmrisc.ProgramExplorer.Syntax.ASTVisitor;

/**
 * A quotient expression.
 */
public final class DividesExpression extends BinaryValueExpression
{
  public final static int precedence  = 12; 
  public final static String operator = "/";
  
  /****************************************************************************
   * Construct a quotient expression.
   * @param first the first (left) part.
   * @param second the right (second) part.
   * @return the expression.
   ***************************************************************************/
  public static DividesExpression 
  construct(ValueExpression first, ValueExpression second)
  {
    return new DividesExpression(first, second);
  }
  
  /****************************************************************************
   * Construct a quotient expression.
   * @param first the first (left) part.
   * @param second the right (second) part.
   ***************************************************************************/
  private DividesExpression(ValueExpression first, ValueExpression second)
  {
    super(first, second);
  }
  
  /***************************************************************************
   * Get precedence value of the expression operator 
   * (higher precedence value means higher binding power)
   **************************************************************************/
  public int getPrecedence()
  {
    return precedence;
  }
  
  /***************************************************************************
   * Get textual representation of operator.
   **************************************************************************/
  public String getOperator()
  {
    return operator;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}
