// ----------------------------------------------------------------------------
// IntLiteral.java
// An integer literal.
// $Id: IntLiteral.java,v 1.4 2017/07/04 08:04:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Program;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * An integer literal.
 */
public final class IntLiteral extends ValueExpressionBase
{
  public static final int precedence = 16;
  public static final IntLiteral one = new IntLiteral("1");
  
  public final String digits;
  
  /****************************************************************************
   * Construction of an integer literal.
   * @param digits the sequence of decimal digits denoting the literal.
   * @return the literal.
   ***************************************************************************/
  public static IntLiteral construct(String digits)
  {
    return new IntLiteral(digits);
  }
  
  /****************************************************************************
   * Construction of an integer literal.
   * @param digits the sequence of decimal digits denoting the literal.
   ***************************************************************************/
  protected IntLiteral(String digits)
  {
    this.digits = digits;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Get precedence value of the expression operator 
   * (higher precedence value means higher binding power)
   **************************************************************************/
  public int getPrecedence()
  {
    return precedence;
  }
}

