// ----------------------------------------------------------------------------
// ObjectVariableDeclaration.java
// An object variable declaration.
// $Id: ObjectVariableDeclaration.java,v 1.4 2017/07/04 08:04:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Program;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * An object variable declaration.
 */
public final class ObjectVariableDeclaration extends GlobalVariableDeclaration
{
  /****************************************************************************
   * Construct an object variable declaration
   * @param name the name of the variable
   * @param type its type
   * @param value its initialization value (may be null)
   * @return the declaration.
   ***************************************************************************/
  public static ObjectVariableDeclaration construct(Identifier name,
    TypeExpression type, ValueExpression value)
  {
    return new ObjectVariableDeclaration(name, type, value);
  }
  
  /****************************************************************************
   * Construct an object variable declaration
   * @param name the name of the variable
   * @param type its type
   * @param value its initialization value (may be null)
   ***************************************************************************/
  private ObjectVariableDeclaration(Identifier name,
    TypeExpression type, ValueExpression value)
  {
    super(name, type, value);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}
