// ----------------------------------------------------------------------------
// ThrowStatement.java
// A throw (exception) statement.
// $Id: ThrowStatement.java,v 1.8 2017/07/04 08:04:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Program;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * A throw (exception statement)
 */
public final class ThrowStatement extends CallStatement
{
  /***************************************************************************
   * Construct a throw (exception) statement.
   * @param name the exception name
   * @param value the exception value
   * @return the statement.
   **************************************************************************/
  public static ThrowStatement construct(Name name, ValueExpression value)
  {
    return new ThrowStatement(name, value);
  } 
  
  /***************************************************************************
   * Construct a throw (exception) statement.
   * @param name the exception name
   * @param value the exception value
   **************************************************************************/
  private ThrowStatement(Name name, ValueExpression value)
  {
    super(name, new ValueExpression[]{ value });
  }    
  
  /***************************************************************************
   * Get the exception value.
   * @return the exception value.
   **************************************************************************/
  public ValueExpression getValue()
  {
    return args[0];
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}
