// ----------------------------------------------------------------------------
// VariableDeclarationBase.java
// The base class of declarations introducing variables with types.
// $Id: VariableDeclarationBase.java,v 1.3 2011/09/30 15:47:35 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Program;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * The base class of declarations introducing variables with types.
 */
public abstract class VariableDeclarationBase 
extends DeclarationBase implements VariableDeclaration
{
  public TypeExpression type;
  
  /****************************************************************************
   * Construct variable declaration.
   * @param name the name of the declared variable.
   * @param type the type of the declared variable.
   ***************************************************************************/
  public VariableDeclarationBase(Identifier name, TypeExpression type)
  {
    super(name);
    this.type = type;
  }
  
  /****************************************************************************
   * Get the type of the declared entity.
   * @return the entity's type.
   ***************************************************************************/
  public TypeExpression getType()
  {
    return type;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    super.accept(visitor);
    type.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    type.accept(visitor);
  }
}
