// ----------------------------------------------------------------------------
// VariableValue.java
// A variable denoting a value.
// $Id: VariableValue.java,v 1.4 2017/07/04 08:04:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Program;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * A variable denoting a value.
 */
public final class VariableValue extends ValueExpressionBase
{
  public static final int precedence = 16;
  
  public final Identifier ident;
  
  /****************************************************************************
   * Construction of a variable denoting a value.
   * @param lval a left value from which the variable is to be constructed.
   * @return the variable.
   ***************************************************************************/
  public static VariableValue construct(LeftValue lval)
  {
    return VariableValue.construct(lval.name);
  }
  
  /****************************************************************************
   * Construction of a variable denoting a value.
   * @param ident the identifier denoting the variable.
   * @return the variable.
   ***************************************************************************/
  public static VariableValue construct(Identifier ident)
  {
    return new VariableValue(ident);
  }
  
  /****************************************************************************
   * Construction of a variable denoting a value.
   * @param ident the identifier denoting the variable.
   ***************************************************************************/
  protected VariableValue(Identifier ident)
  {
    this.ident = ident;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    ident.accept(visitor);
  }
  
  /***************************************************************************
   * Get precedence value of the expression operator 
   * (higher precedence value means higher binding power)
   **************************************************************************/
  public int getPrecedence()
  {
    return precedence;
  }
}




