// ----------------------------------------------------------------------------
// WhileLoopStatement.java
// A while loop.
// $Id: WhileLoopStatement.java,v 1.6 2017/07/04 08:04:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Program;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * A while loop.
 */
public final class WhileLoopStatement extends LoopStatementBase
{
  public final ValueExpression cond;
  public final Statement body;
  
  /***************************************************************************
   * Construct a while loop.
   * @param cond the loop condition.
   * @param body the loop body
   * @return the loop.
   **************************************************************************/
  public static WhileLoopStatement construct(ValueExpression cond, 
    Statement body)
  {
    return new WhileLoopStatement(cond, body);
  } 
  
  /***************************************************************************
   * Construct a while loop.
   * @param cond the loop condition.
   * @param body the loop body.
   **************************************************************************/
  private WhileLoopStatement(ValueExpression cond, Statement body)
  {
    this.cond = cond;
    this.body = body;
  }    
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
    cond.accept(visitor);
    body.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    cond.accept(visitor);
    body.accept(visitor);
  }
  
  /****************************************************************************
   * Get type of statement.
   * @return a string identifying the type of statement.
   ***************************************************************************/
  public String getKind()
  {
    return "while loop";
  }
}
