// ----------------------------------------------------------------------------
// Goto.java
// The "goto" command.
// $Id: Goto.java,v 1.7 2008/10/13 09:32:00 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Commands;

import java.io.PrintWriter;

import fmrisc.ProofNavigator.Proving.*;

/**
 * 
 * The "goto" command: goto an open proof state.
 *
 */
public final class Goto extends ProofCommandBase
{
  public final static String Name = "goto";
  private String label; // the label of the proof state to go to
  
  /***************************************************************************
   * create a "goto" command
   * @param label the label of the proof state to go to
   **************************************************************************/
  public Goto(String label)
  {
    super(Name);
    this.label = label;
  }
  
  /****************************************************************************
   * Process command "goto": switch to the denoted state.
   * @param state the state to which the command is applied
   * @return null
   ***************************************************************************/
  protected ProofState[] processCore(ProofState state)
  {
    Proof proof = state.getProof();
    if (proof == null)
    {
      error("command only allowed in proof mode");
      return null;
    }
    state = proof.getState(label);
    if (state == null)
    {
      error("there is no state with label [" + label + "]");
      return null;
    }
    if (state.isClosed())
    {
      error("cannot go to closed state " + label + 
        " (use \"undo " + label + "\")");
      return null;
    }
    proof.setCurrent(state);
    return null;
  }
  
  /***************************************************************************
   * Prints text representation on out (without new line termination).
   * @param out the stream on which the text is written
   **************************************************************************/
  public void printCore(PrintWriter out)
  {
    out.print(getName());
    out.print(" ");
    out.print(label);
  }
}
