// ----------------------------------------------------------------------------
// TypeTable.java
// Type table for type checking.
// $Id: TypeTable.java,v 1.11 2017/07/04 08:04:35 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Semantics;

import fmrisc.ProofNavigator.Syntax.*;

/**
 * 
 * Type table for type checking.
 *
 */
public final class TypeTable extends SymbolTable
{
  /****************************************************************************
   * creates a clone of the symbol table, the clone is a shallow copy
   * (the symbols in the table are not cloned)
   * @return the clone.
   ***************************************************************************/
  public TypeTable cloneTypeTable()
  {
    return (TypeTable)(super.cloneTable(new TypeTable()));
  }
  
  /****************************************************************************
   * put type in type table
   * @param key the name of the type
   * @param type the type associated to the name
   * @return constructed symbol (null, if an error occured)
   ***************************************************************************/
  public TypeSymbol put(TypeDeclIdentifier key, Type type)
  {
    TypeSymbol symbol = key.getSymbol();
    symbol.setType(type);
    super.put(key, symbol); 
    return symbol;
  }
  
  /****************************************************************************
   * returns symbol associated to name (null, if none)
   * @param name the name 
   * @return the symbol associated to the name (may be null)
   ***************************************************************************/
  public TypeSymbol getSymbol(Identifier name)
  {
    return (TypeSymbol)(get(name));
  }
  
  /****************************************************************************
   * returns canonical type associated to key
   * type equality implies pointer equality of types.
   * @param key the name of the type
   * @return the canonical type associated to key
   ***************************************************************************/
  public Type getType(Identifier key)
  {
    TypeSymbol symbol = getSymbol(key);
    if (symbol == null) return null;
    return symbol.getType();
  }
}
