// ----------------------------------------------------------------------------
// ValueTable.java
// Value table for named value lookup.
// $Id: ValueTable.java,v 1.18 2017/07/04 08:04:35 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Semantics;

import fmrisc.ProofNavigator.Syntax.*;

/**
 * 
 * Value table for named value lookup.
 *
 */
public final class ValueTable extends SymbolTable
{
  /****************************************************************************
   * creates a clone of the symbol table, the clone is a shallow copy
   * (the symbols in the table are not cloned)
   * @return the clone.
   ***************************************************************************/
  public ValueTable cloneValueTable()
  {
    return (ValueTable)(super.cloneTable(new ValueTable()));
  }
  
  /****************************************************************************
   * put named value in value table
   * @param name the name of the value
   * @param type the type associated to the value
   * @param value the value itself (may be null)
   * @param depth the current environment depth
   * @return constructed symbol (null, if an error occured)
   ***************************************************************************/
  public ValueSymbol put(ValueDeclIdentifier name, Type type, 
    Expression value, int depth)
  {
    ValueSymbol symbol = name.getSymbol();
    symbol.setType(type);
    symbol.setValue(value);
    symbol.setDepth(depth);
    TypeExpression te = Checking.clearSubtypes(type, 
      Construct.reference(symbol.getValueDeclIdentifier()));
    symbol.setClearType(te);
    put(name, symbol);
    return symbol;
  }
  
  /****************************************************************************
   * returns symbol associated to name (null, if none)
   * @param name the name 
   * @return the symbol associated to the name (may be null)
   ***************************************************************************/
  public ValueSymbol getSymbol(Identifier name)
  {
    return (ValueSymbol)(get(name));
  }
}
