// ----------------------------------------------------------------------------
// AxiomDeclaration.java
// Handling of axiom declarations.
// $Id: AxiomDeclaration.java,v 1.4 2008/10/13 09:32:00 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Syntax;

import java.io.*;

/**
 * Handling of type declarations.
 */
public final class AxiomDeclaration extends FormulaDeclaration
{
  /*****************************************************************************
   * Construct axiom declaration with denoted name and formula.
   * @param name the declared name
   * @param formula the formula associated to the name 
   ****************************************************************************/
  public AxiomDeclaration(FormulaDeclIdentifier name, Expression formula)
  {
    super(name, formula);
  }

  /*****************************************************************************
   * Prints text representation of tree on out (without new line termination).
   * @param out the stream on which the text is written
   ****************************************************************************/
  public void printCore(PrintWriter out)
  {
    getIdentifier().print(out);
    out.print(": AXIOM ");
    getFormula().print(out);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   * @return the result of the visit (may be null)
   **************************************************************************/
  public AST accept(ASTVisitor visitor) 
  { 
    AST result = visitor.visit(this);
    if (result != null) return result;
    AST name0 = getFormulaDeclIdentifier().accept(visitor);
    AST formula0 = getFormula().accept(visitor);
    if (!visitor.isCloned()) return null;
    return Construct.axiomDeclaration(
      (FormulaDeclIdentifier)name0, (Expression)formula0);
  }
}
